From 9348abeab1bf1052bdc6e9770a4e94723a8cb6a2 Mon Sep 17 00:00:00 2001
From: Nagy Gabor <ngaba@bibl.u-szeged.hu>
Date: Fri, 29 Feb 2008 23:22:18 +0100
Subject: [PATCH] testpkg rework

* mainly code cosmetics (indent fixes)
* remove debug message "spam"
* print also user friendly result
* first stat the file (alpm_pkg_load never reports PM_ERR_PKG_NOT_FOUND)

Signed-off-by: Nagy Gabor <ngaba@bibl.u-szeged.hu>
---
 src/util/testpkg.c |   45 +++++++++++++++++++++++++++++----------------
 1 files changed, 29 insertions(+), 16 deletions(-)

diff --git a/src/util/testpkg.c b/src/util/testpkg.c
index e32b013..7534e92 100644
--- a/src/util/testpkg.c
+++ b/src/util/testpkg.c
@@ -22,6 +22,10 @@
 #include <stdio.h> /* printf */
 #include <stdarg.h> /* va_list */
 #include <string.h> /* strlen */
+#include <sys/types.h> /* stat */
+#include <sys/stat.h>
+#include <unistd.h>
+
 
 #include <alpm.h>
 
@@ -29,44 +33,53 @@
 
 static void output_cb(pmloglevel_t level, char *fmt, va_list args)
 {
-	if(strlen(fmt)) {
-        switch(level) {
-        case PM_LOG_ERROR: printf("error: "); break;
-        case PM_LOG_WARNING: printf("warning: "); break;
-		default: break;
-        }
-		vprintf(fmt, args);
-    }
+	if(fmt[0] == '\0') {
+		return;
+	}
+ 	switch(level) {
+		case PM_LOG_ERROR: printf("error: "); break;
+		case PM_LOG_WARNING: printf("warning: "); break;
+		default: return; /* skip other messages */
+	}
+	vprintf(fmt, args);
 }
 
 int main(int argc, char **argv)
 {
-    int retval = 1; /* default = false */
-    pmpkg_t *pkg = NULL;
+	int retval = 1; /* default = false */
+	pmpkg_t *pkg = NULL;
+	struct stat buf;
 
-    if(argc != 2) {
+	if(argc != 2) {
 		fprintf(stderr, "usage: %s <package file>\n", BASENAME);
 		return(1);
 	}
 
+	if(stat(argv[1], &buf) == -1) {
+		fprintf(stderr, "Package file was not found.\n");
+		return(1);
+	}
+
 	if(alpm_initialize() == -1) {
 		fprintf(stderr, "cannot initilize alpm: %s\n", alpm_strerrorlast());
-        return(1);
+		return(1);
 	}
 
-    /* let us get log messages from libalpm */
+	/* let us get log messages from libalpm */
 	alpm_option_set_logcb(output_cb);
 
 	if(alpm_pkg_load(argv[1], 1, &pkg) == -1 || pkg == NULL) {
-        retval = 1;
+		printf("Package is invalid.\n");
+		retval = 1;
 	} else {
 		alpm_pkg_free(pkg);
-        retval = 0;
+		printf("Package is valid.\n");
+		retval = 0;
 	}
 
 	if(alpm_release() == -1) {
 		fprintf(stderr, "error releasing alpm: %s\n", alpm_strerrorlast());
 	}
 
-    return(retval);
+	return(retval);
 }
-- 
1.5.3.7

